@@ -23,6 +23,7 @@ from stevedore import driver as stevedore_driver
 from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions
 from octavia_lib.api.drivers import provider_base as driver_base
+from octavia_lib.common import constants as lib_consts
 
 from octavia.api.drivers.amphora_driver import availability_zone_schema
 from octavia.api.drivers.amphora_driver import flavor_schema
@@ -43,6 +44,16 @@ AMPHORA_SUPPORTED_LB_ALGORITHMS = [
     consts.LB_ALGORITHM_SOURCE_IP,
     consts.LB_ALGORITHM_LEAST_CONNECTIONS]
 
+AMPHORA_SUPPORTED_PROTOCOLS = [
+    lib_consts.PROTOCOL_TCP,
+    lib_consts.PROTOCOL_HTTP,
+    lib_consts.PROTOCOL_HTTPS,
+    lib_consts.PROTOCOL_TERMINATED_HTTPS,
+    lib_consts.PROTOCOL_PROXY,
+    lib_consts.PROTOCOL_PROXYV2,
+    lib_consts.PROTOCOL_UDP,
+]
+
 
 class AmphoraProviderDriver(driver_base.ProviderDriver):
     def __init__(self):
@@ -62,6 +73,16 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                 user_fault_string=msg,
                 operator_fault_string=msg)
 
+    def _validate_listener_protocol(self, listener):
+        if listener.protocol not in AMPHORA_SUPPORTED_PROTOCOLS:
+            msg = ('Amphora provider does not support %s protocol. '
+                   'Supported: %s'
+                   % (listener.protocol,
+                      ", ".join(AMPHORA_SUPPORTED_PROTOCOLS)))
+            raise exceptions.UnsupportedOptionError(
+                user_fault_string=msg,
+                operator_fault_string=msg)
+
     def _validate_alpn_protocols(self, listener):
         if not listener.alpn_protocols:
             return
@@ -82,6 +103,13 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                                           project_id=project_id, vip=vip_obj)
 
         network_driver = utils.get_network_driver()
+        vip_network = network_driver.get_network(
+            vip_dictionary[lib_consts.VIP_NETWORK_ID])
+        if not vip_network.port_security_enabled:
+            message = "Port security must be enabled on the VIP network."
+            raise exceptions.DriverError(user_fault_string=message,
+                                         operator_fault_string=message)
+
         try:
             vip = network_driver.allocate_vip(lb_obj)
         except network_base.AllocateVIPException as e:
@@ -136,6 +164,7 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
 
     # Listener
     def listener_create(self, listener):
+        self._validate_listener_protocol(listener)
         self._validate_alpn_protocols(listener)
         payload = {consts.LISTENER_ID: listener.listener_id}
         self.client.cast({}, 'create_listener', **payload)
@@ -183,16 +212,16 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             pool_dict['enabled'] = pool_dict.pop('admin_state_up')
         pool_id = pool_dict.pop('pool_id')
         if 'tls_container_ref' in pool_dict:
-            pool_dict['tls_container_id'] = pool_dict.pop('tls_container_ref')
+            pool_dict['tls_certificate_id'] = pool_dict.pop(
+                'tls_container_ref')
         pool_dict.pop('tls_container_data', None)
         if 'ca_tls_container_ref' in pool_dict:
             pool_dict['ca_tls_certificate_id'] = pool_dict.pop(
                 'ca_tls_container_ref')
         pool_dict.pop('ca_tls_container_data', None)
-        if 'client_crl_container_ref' in pool_dict:
-            pool_dict['client_crl_container_id'] = pool_dict.pop(
-                'client_crl_container_ref')
-        pool_dict.pop('client_crl_container_data', None)
+        if 'crl_container_ref' in pool_dict:
+            pool_dict['crl_container_id'] = pool_dict.pop('crl_container_ref')
+        pool_dict.pop('crl_container_data', None)
 
         payload = {consts.POOL_ID: pool_id,
                    consts.POOL_UPDATES: pool_dict}
@@ -256,13 +285,10 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             if m.id not in new_member_ids:
                 deleted_members.append(m)
 
-        if deleted_members or new_members or updated_members:
-            payload = {'old_member_ids': [m.id for m in deleted_members],
-                       'new_member_ids': [m.member_id for m in new_members],
-                       'updated_members': updated_members}
-            self.client.cast({}, 'batch_update_members', **payload)
-        else:
-            LOG.info("Member batch update is a noop, returning early.")
+        payload = {'old_member_ids': [m.id for m in deleted_members],
+                   'new_member_ids': [m.member_id for m in new_members],
+                   'updated_members': updated_members}
+        self.client.cast({}, 'batch_update_members', **payload)
 
     def _validate_members(self, db_pool, members):
         if db_pool.protocol == consts.PROTOCOL_UDP:
